@@ -1,6 +1,7 @@
 use alloc::collections::btree_map::BTreeMap as HashMap;
 
-use abscissa_core::{Clap, Command, Runnable};
+use abscissa_core::clap::Parser;
+use abscissa_core::{Command, Runnable};
 
 use ibc::core::ics24_host::identifier::ChainId;
 use ibc_relayer::{
@@ -11,9 +12,9 @@ use ibc_relayer::{
 use crate::conclude::Output;
 use crate::{application::app_config, conclude::json};
 
-#[derive(Clone, Command, Debug, Clap)]
+#[derive(Clone, Command, Debug, Parser)]
 pub struct KeysListCmd {
-    #[clap(required = true, about = "identifier of the chain")]
+    #[clap(required = true, help = "identifier of the chain")]
     chain_id: ChainId,
 }
 
