@@ -1,6 +1,7 @@
 use alloc::sync::Arc;
 
-use abscissa_core::{Clap, Runnable};
+use abscissa_core::clap::Parser;
+use abscissa_core::Runnable;
 use tokio::runtime::Runtime as TokioRuntime;
 
 use ibc::core::ics24_host::identifier::{ChainId, ConnectionId};
@@ -10,9 +11,9 @@ use ibc_relayer::chain::{ChainEndpoint, CosmosSdkChain};
 use crate::conclude::{exit_with_unrecoverable_error, Output};
 use crate::prelude::*;
 
-#[derive(Clone, Command, Debug, Clap)]
+#[derive(Clone, Command, Debug, Parser)]
 pub struct QueryConnectionsCmd {
-    #[clap(required = true, about = "identifier of the chain to query")]
+    #[clap(required = true, help = "identifier of the chain to query")]
     chain_id: ChainId,
 }
 
