@@ -1,6 +1,7 @@
 use core::fmt;
 
-use abscissa_core::{Clap, Command, Runnable};
+use abscissa_core::clap::Parser;
+use abscissa_core::{Command, Runnable};
 
 use ibc::core::ics02_client::client_state::ClientState;
 use ibc::core::ics24_host::identifier::{ChainId, ClientId};
@@ -8,20 +9,45 @@ use ibc::events::IbcEvent;
 use ibc_proto::ibc::core::client::v1::QueryClientStatesRequest;
 use ibc_relayer::chain::handle::ChainHandle;
 use ibc_relayer::config::Config;
-use ibc_relayer::foreign_client::ForeignClient;
+use ibc_relayer::foreign_client::{CreateParams, ForeignClient};
+use tendermint_light_client_verifier::types::TrustThreshold;
 
 use crate::application::app_config;
 use crate::cli_utils::{spawn_chain_runtime, spawn_chain_runtime_generic, ChainHandlePair};
 use crate::conclude::{exit_with_unrecoverable_error, Output};
 use crate::error::Error;
 
-#[derive(Clone, Command, Debug, Clap)]
+#[derive(Clone, Command, Debug, Parser)]
 pub struct TxCreateClientCmd {
-    #[clap(required = true, about = "identifier of the destination chain")]
+    #[clap(required = true, help = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[clap(required = true, about = "identifier of the source chain")]
+    #[clap(required = true, help = "identifier of the source chain")]
     src_chain_id: ChainId,
+
+    /// Override the default clock drift specified in the configuration.
+    ///
+    /// The clock drift is a correction parameter dealing with only approximately synchronized clocks.
+    /// The local clock should always be ahead of timestamps from the blockchain; this
+    /// is the maximum amount that the local clock may drift behind a timestamp from the
+    /// blockchain.
+    #[clap(short = 'd', long)]
+    clock_drift: Option<humantime::Duration>,
+
+    /// Override the trusting period specified in the config.
+    ///
+    /// The trusting period specifies how long a validator set is trusted for
+    /// (must be shorter than the chain's unbonding period).
+
+    #[clap(short = 'p', long)]
+    trusting_period: Option<humantime::Duration>,
+
+    /// Override the trust threshold specified in the configuration.
+    ///
+    /// The trust threshold defines what fraction of the total voting power of a known
+    /// and trusted validator set is sufficient for a commit to be accepted going forward.
+    #[clap(short = 't', long, parse(try_from_str = parse_trust_threshold))]
+    trust_threshold: Option<TrustThreshold>,
 }
 
 /// Sample to run this tx:
@@ -41,9 +67,15 @@ impl Runnable for TxCreateClientCmd {
 
         let client = ForeignClient::restore(ClientId::default(), chains.dst, chains.src);
 
+        let params = CreateParams {
+            clock_drift: self.clock_drift.map(Into::into),
+            trusting_period: self.trusting_period.map(Into::into),
+            trust_threshold: self.trust_threshold,
+        };
+
         // Trigger client creation via the "build" interface, so that we obtain the resulting event
         let res: Result<IbcEvent, Error> = client
-            .build_create_client_and_send()
+            .build_create_client_and_send(&params)
             .map_err(Error::foreign_client);
 
         match res {
@@ -53,21 +85,21 @@ impl Runnable for TxCreateClientCmd {
     }
 }
 
-#[derive(Clone, Command, Debug, Clap)]
+#[derive(Clone, Command, Debug, Parser)]
 pub struct TxUpdateClientCmd {
-    #[clap(required = true, about = "identifier of the destination chain")]
+    #[clap(required = true, help = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
     #[clap(
         required = true,
-        about = "identifier of the client to be updated on destination chain"
+        help = "identifier of the client to be updated on destination chain"
     )]
     dst_client_id: ClientId,
 
-    #[clap(short = 'H', long, about = "the target height of the client update")]
+    #[clap(short = 'H', long, help = "the target height of the client update")]
     target_height: Option<u64>,
 
-    #[clap(short = 't', long, about = "the trusted height of the client update")]
+    #[clap(short = 't', long, help = "the trusted height of the client update")]
     trusted_height: Option<u64>,
 }
 
@@ -121,15 +153,15 @@ impl Runnable for TxUpdateClientCmd {
     }
 }
 
-#[derive(Clone, Command, Debug, Clap)]
+#[derive(Clone, Command, Debug, Parser)]
 pub struct TxUpgradeClientCmd {
     #[clap(
         required = true,
-        about = "identifier of the chain that hosts the client"
+        help = "identifier of the chain that hosts the client"
     )]
     chain_id: ChainId,
 
-    #[clap(required = true, about = "identifier of the client to be upgraded")]
+    #[clap(required = true, help = "identifier of the client to be upgraded")]
     client_id: ClientId,
 }
 
@@ -171,11 +203,11 @@ impl Runnable for TxUpgradeClientCmd {
     }
 }
 
-#[derive(Clone, Command, Debug, Clap)]
+#[derive(Clone, Command, Debug, Parser)]
 pub struct TxUpgradeClientsCmd {
     #[clap(
         required = true,
-        about = "identifier of the chain that underwent an upgrade; all clients targeting this chain will be upgraded"
+        help = "identifier of the chain that underwent an upgrade; all clients targeting this chain will be upgraded"
     )]
     src_chain_id: ChainId,
 }
@@ -238,6 +270,22 @@ impl TxUpgradeClientsCmd {
     }
 }
 
+fn parse_trust_threshold(input: &str) -> Result<TrustThreshold, Error> {
+    let (num_part, denom_part) = input.split_once('/').ok_or_else(|| {
+        Error::cli_arg("expected a fractional argument, two numbers separated by '/'".into())
+    })?;
+    let numerator = num_part
+        .trim()
+        .parse()
+        .map_err(|_| Error::cli_arg("invalid numerator for the fraction".into()))?;
+    let denominator = denom_part
+        .trim()
+        .parse()
+        .map_err(|_| Error::cli_arg("invalid denominator for the fraction".into()))?;
+    TrustThreshold::new(numerator, denominator)
+        .map_err(|e| Error::cli_arg(format!("invalid trust threshold fraction: {}", e)))
+}
+
 type UpgradeClientResult = Result<Vec<IbcEvent>, Error>;
 type UpgradeClientsForChainResult = Result<Vec<UpgradeClientResult>, Error>;
 
@@ -269,11 +317,11 @@ impl fmt::Display for OutputBuffer {
                         )?;
                         match inner_result {
                             Ok(events) => writeln!(f, "{:#?}", events)?,
-                            Err(e) => writeln!(f, "{}", e.to_string())?,
+                            Err(e) => writeln!(f, "{}", e)?,
                         }
                     }
                 }
-                Err(e) => writeln!(f, " {}", e.to_string())?,
+                Err(e) => writeln!(f, " {}", e)?,
             }
         }
         Ok(())
@@ -310,3 +358,23 @@ impl OutputBuffer {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::parse_trust_threshold;
+
+    #[test]
+    fn test_parse_trust_threshold() {
+        let threshold = parse_trust_threshold("3/5").unwrap();
+        assert_eq!(threshold.numerator(), 3);
+        assert_eq!(threshold.denominator(), 5);
+
+        let threshold = parse_trust_threshold("3 / 5").unwrap();
+        assert_eq!(threshold.numerator(), 3);
+        assert_eq!(threshold.denominator(), 5);
+
+        let threshold = parse_trust_threshold("\t3 / 5  ").unwrap();
+        assert_eq!(threshold.numerator(), 3);
+        assert_eq!(threshold.denominator(), 5);
+    }
+}
